==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/fil-PH/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Accessory_Checkout_Notification' => 'Accessory checked out',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'Asset_Checkout_Notification' => 'Asset checked out',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Consumable_checkout_notification' => 'Consumable checked out',
    'Days' => 'Mga araw',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expiring_Assets_Report' => 'Ang Pa-expire na Report sa mga Asset.',
    'Expiring_Licenses_Report' => 'Ang Pa-expire na Report sa mga Lisensya.',
    'Item_Request_Canceled' => 'Ang Rekwest na Aytem ay Nakansela',
    'Item_Requested' => 'Ang Nirekwest na Aytem',
    'License_Checkin_Notification' => 'License checked in',
    'License_Checkout_Notification' => 'License checked out',
    'license_for'   => 'License for',
    'Low_Inventory_Report' => 'Ang Mababang Report ng Imbentaryo',
    'a_user_canceled' => 'Ang gumagamit o user ay nag-kansela ng rekwest na aytem sa website',
    'a_user_requested' => 'Ang gumagamit ay nag-rekwest ng aytem sa website',
    'acceptance_asset_accepted' => 'A user has accepted an item',
    'acceptance_asset_declined' => 'A user has declined an item',
    'accessory_name' => 'Ang Pangalan ng Aksesorya',
    'additional_notes' => 'Ang mga Karagdagang mga Lista',
    'admin_has_created' => 'Ang tagapangasiwa ay nakapagsagawa ng isang account para sa iyo sa :web website.',
    'asset' => 'Ang Asset',
    'asset_name' => 'Ang Pangalan ng Asset',
    'asset_requested' => 'Ang nirekwest na asset',
    'asset_tag' => 'Ang Tag ng Asset',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'assigned_to' => 'Nakatalaga Sa',
    'best_regards' => 'Lubos na bumabati,',
    'canceled' => 'Nakansela',
    'checkin_date' => 'Ang Petsa ng Pag-checkin',
    'checkout_date' => 'Ang Petsa ng Pagcheck-out',
    'checkedout_from' => 'Checked out from',
    'checkedin_from'  => 'Checked in from',
    'checked_into' => 'Checked into',
    'click_on_the_link_accessory' => 'Paki-klik sa link na nasa ibaba para i-komperma na ikaw ay nakakatanggap ng aksesorya.',
    'click_on_the_link_asset' => 'Paki-klik sa link na nasa ibaba para i-komperma na ikaw ay nakakatanggap ng asset.',
    'click_to_confirm' => 'Paki-klik sa mga sumusunod na link para i-komperma ang iyong :web account:',
    'current_QTY' => 'Ang kasalukuyang QTY',
    'days' => 'Mga araw',
    'expecting_checkin_date' => 'Ang Inaasahang Petsa ng Pag-checkin',
    'expires' => 'Mawalang bisa',
    'hello' => 'Kumusta',
    'hi' => 'Kumusta',
    'i_have_read' => 'Ako ay nakabasa ay sumasang-ayon sa mga tuntunin ng paggamit, at ang aytem na ito ay aking tinatanggap.',
    'inventory_report' => 'Inventory Report',
    'item' => 'Ang Aytem',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'link_to_update_password' => 'Paki-klik sa mga sumusunod na link para makapag-update sa iyong :web password:',
    'login' => 'Mag-login',
    'login_first_admin' => 'Mag-login sa iyong bagong pag-install ng Snipe-IT gamit ang mga kredensyal sa ibaba:',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'min_QTY' => 'Ang Min QTY',
    'name' => 'Ang Pangalan',
    'new_item_checked' => 'Ang bagong aytem na nai-check out sa ilalim ng iyong pangalan, ang mga detalye ay nasa ibaba.',
    'notes' => 'Ang mga Palatandaan',
    'password' => 'Ang Password',
    'password_reset' => 'Ang Pagbago ng Password',
    'read_the_terms' => 'Paki-basa sa mga tuntunin ng paggamit sa ibaba.',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read and agree to the terms of use, and have received the asset.',
    'requested' => 'Ang Nirekwest',
    'reset_link' => 'Ang Link para sa Pag-reset ng Password',
    'reset_password' => 'I-klik ito para ma-reset ang iyong password:',
    'rights_reserved' => 'All rights reserved.',
    'serial' => 'Ang Seryal',
    'snipe_webhook_test' => 'Snipe-IT Integration Test',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Summary',
    'supplier' => 'Ang Tagapagsuplay',
    'tag' => 'Ang Tag',
    'test_email' => 'I-test ang Email mula sa Snipe-IT',
    'test_mail_text' => 'Ito ay isang test mula sa Snipe-IT Asset Management System. Kung natanggap mo ito, ang mail na ito ay gumagana :)',
    'the_following_item' => 'Ang mga sumusunod na mga aytem ay nai-check in: ',
    'to_reset' => 'Para mai-reset ang iyong :web password, kumpletuhin ang form na ito:',
    'type' => 'Klase',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Ang gumagamit',
    'username' => 'Ang pangalan ng gumagamit',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Maligayang pagdating :ang pangalan',
    'welcome_to' => 'Maligayang pagdating sa: web!',
    'your_assets' => 'View Your Assets',
    'your_credentials' => 'Ang iyong mga Kredensyal sa Snipe-IT',
    'mail_sent' => 'Mail sent successfully!',
];

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/fil-PH/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Accessory_Checkout_Notification' => 'Accessory checked out|:count Accessories checked out',
    'Asset_Checkin_Notification' => 'Asset checked in: :tag',
    'Asset_Checkout_Notification' => 'Asset checked out: :tag',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_component_checkin' => 'Component checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'Confirm_component_delivery' => 'Component delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Consumable_checkout_notification' => 'Consumable checked out',
    'Component_checkout_notification' => 'Component checked out',
    'Component_checkin_notification' => 'Component checked in',
    'Days' => 'Mga araw',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expiring_Assets_Report' => 'Ang Pa-expire na Report sa mga Asset',
    'Expiring_Licenses_Report' => 'Ang Pa-expire na Report sa mga Lisensya',
    'Item_Request_Canceled' => 'Ang Rekwest na Aytem ay Nakansela',
    'Item_Requested' => 'Ang Nirekwest na Aytem',
    'License_Checkin_Notification' => 'License checked in',
    'License_Checkout_Notification' => 'License checked out',
    'license_for'   => 'License for',
    'Low_Inventory_Report' => 'Ang Mababang Report ng Imbentaryo',
    'a_user_canceled' => 'Ang gumagamit o user ay nag-kansela ng rekwest na aytem sa website',
    'a_user_requested' => 'Ang gumagamit ay nag-rekwest ng aytem sa website',
    'acceptance_asset_accepted_to_user' => 'You have accepted an item assigned to you by :site_name|You have accepted :qty items assigned to you by :site_name',
    'acceptance_asset_accepted' => 'A user has accepted an item',
    'acceptance_asset_declined' => 'A user has declined an item',
    'send_pdf_copy' => 'Send a copy of this acceptance to my email address',
    'accessory_name' => 'Ang Pangalan ng Aksesorya',
    'additional_notes' => 'Ang mga Karagdagang mga Lista',
    'admin_has_created' => 'An administrator has created an account for you on the :web website. Please find your username below, and click on the link to set a password.',
    'asset' => 'Ang Asset',
    'asset_name' => 'Ang Pangalan ng Asset',
    'asset_requested' => 'Ang nirekwest na asset',
    'asset_tag' => 'Ang Tag ng Asset',
    'assets_warrantee_alert' => 'There is :count asset with an expiring warranty or that are reaching their end of life in the next :threshold days.|There are :count assets with expiring warranties or that are reaching their end of life in the next :threshold days.',
    'assigned_to' => 'Nakatalaga Sa',
    'eol' => 'Ang EOL',
    'best_regards' => 'Lubos na bumabati,',
    'canceled' => 'Nakansela',
    'checkin_date' => 'Ang Petsa ng Pag-checkin',
    'checkout_date' => 'Ang Petsa ng Pagcheck-out',
    'checkedout_from' => 'Checked out from',
    'checkedin_from'  => 'Checked in from',
    'checked_into' => 'Checked into',
    'click_on_the_link_accessory' => 'Paki-klik sa link na nasa ibaba para i-komperma na ikaw ay nakakatanggap ng aksesorya.',
    'click_on_the_link_asset' => 'Paki-klik sa link na nasa ibaba para i-komperma na ikaw ay nakakatanggap ng asset.',
    'click_to_confirm' => 'Paki-klik sa mga sumusunod na link para i-komperma ang iyong :web account:',
    'current_QTY' => 'Ang kasalukuyang QTY',
    'days' => 'Mga araw',
    'expecting_checkin_date' => 'Ang Inaasahang Petsa ng Pag-checkin',
    'expires' => 'Mawalang bisa',
    'terminates' => 'Terminates',
    'following_accepted' => 'The following was accepted',
    'following_declined' => 'The following was declined',
    'hello' => 'Kumusta',
    'hi' => 'Kumusta',
    'i_have_read' => 'Ako ay nakabasa ay sumasang-ayon sa mga tuntunin ng paggamit, at ang aytem na ito ay aking tinatanggap.',
    'initiated_accepted' => 'A checkout you initiated was accepted',
    'initiated_declined' => 'A checkout you initiated was declined',
    'inventory_report' => 'Inventory Report',
    'item' => 'Ang Aytem',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'There is :count license expiring or terminating in the next :threshold days.|There are :count licenses expiring or terminating in the next :threshold days.',
    'link_to_update_password' => 'Paki-klik sa mga sumusunod na link para makapag-update sa iyong :web password:',
    'login' => 'Mag-login',
    'login_first_admin' => 'Mag-login sa iyong bagong pag-install ng Snipe-IT gamit ang mga kredensyal sa ibaba:',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'min_QTY' => 'Ang Min QTY',
    'name' => 'Ang Pangalan',
    'new_item_checked' => 'A new item has been checked out under your name, details are below.|:count new items have been checked out under your name, details are below.',
    'new_item_checked_with_acceptance' => 'A new item has been checked out under your name that requires acceptance, details are below.|:count new items have been checked out under your name that requires acceptance, details are below.',
    'new_item_checked_location' => 'A new item has been checked out to :location, details are below.|:count new items have been checked out to :location, details are below.',
    'recent_item_checked' => 'An item was recently checked out under your name that requires acceptance, details are below.',
    'notes' => 'Ang mga Palatandaan',
    'password' => 'Ang Password',
    'password_reset' => 'Ang Pagbago ng Password',
    'read_the_terms' => 'Paki-basa sa mga tuntunin ng paggamit sa ibaba.',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read and agree to the terms of use, and have received the asset.',
    'requested' => 'Ang Nirekwest',
    'reset_link' => 'Ang Link para sa Pag-reset ng Password',
    'reset_password' => 'I-klik ito para ma-reset ang iyong password:',
    'rights_reserved' => 'All rights reserved.',
    'serial' => 'Ang Seryal',
    'snipe_webhook_test' => 'Snipe-IT Integration Test',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Summary',
    'supplier' => 'Ang Tagapagsuplay',
    'tag' => 'Ang Tag',
    'test_email' => 'I-test ang Email mula sa Snipe-IT',
    'test_mail_text' => 'Ito ay isang test mula sa Snipe-IT Asset Management System. Kung natanggap mo ito, ang mail na ito ay gumagana :)',
    'the_following_item' => 'Ang mga sumusunod na mga aytem ay nai-check in: ',
    'to_reset' => 'Para mai-reset ang iyong :web password, kumpletuhin ang form na ito:',
    'type' => 'Klase',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Ang gumagamit',
    'username' => 'Ang pangalan ng gumagamit',
    'unaccepted_asset_reminder' => 'Reminder: You have Unaccepted Assets.',
    'welcome' => 'Maligayang pagdating :ang pangalan',
    'welcome_to' => 'Maligayang pagdating sa: web!',
    'your_assets' => 'View Your Assets',
    'your_credentials' => 'Ang iyong mga Kredensyal sa Snipe-IT',
    'mail_sent' => 'Mail sent successfully!',
];
